/*!
 * Copyright (c) Microsoft Corporation and contributors. All rights reserved.
 * Licensed under the MIT License.
 */
/**
 * Utility for producing an enriched commit out of multiple transaction steps
 */
export class TransactionEnricher {
    constructor(rebaser, enricher) {
        this.transactionCommits = [];
        this.rebaser = rebaser;
        this.enricher = enricher;
    }
    addTransactionSteps(commit) {
        const change = this.enricher.updateChangeEnrichments(commit.change, commit.revision);
        this.transactionCommits.push({ ...commit, change });
    }
    getComposedChange(revision) {
        const squashed = this.rebaser.compose(this.transactionCommits);
        const tagged = this.rebaser.changeRevision(squashed, revision);
        return tagged;
    }
}
//# sourceMappingURL=transactionEnricher.js.map